<p align="center">
<img width=50% src="docs/_static/logo.png" alt="Featuretools" />
</p>

<p align="center">
<i>"Because feature engineering should be a science and not an art."</i>
</p>

Featuristic uses Genetic Algorithms to automate the process of feature engineering and feature selection, enhancing the performance of machine learning models by optimizing their predictive capabilities.

See the documentation for more information.

## Installation
Install with pip

```
python -m pip install featuristic
```
